==> zio-aws-s3_2.12-6.20.78.3-sources.jar: zio/aws/s3/model/GetObjectTorrentResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import zio.prelude.data.Optional
import scala.jdk.CollectionConverters._
final case class GetObjectTorrentResponse(
    requestCharged: Optional[zio.aws.s3.model.RequestCharged] = Optional.Absent
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse = {
    import GetObjectTorrentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
      .builder()
      .optionallyWith(requestCharged.map(value => value.unwrap))(
        _.requestCharged
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.GetObjectTorrentResponse.ReadOnly =
    zio.aws.s3.model.GetObjectTorrentResponse.wrap(buildAwsValue())
}
object GetObjectTorrentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetObjectTorrentResponse = zio.aws.s3.model
      .GetObjectTorrentResponse(requestCharged.map(value => value))
    def requestCharged: Optional[zio.aws.s3.model.RequestCharged]
    def getRequestCharged: ZIO[Any, AwsError, zio.aws.s3.model.RequestCharged] =
      AwsError.unwrapOptionField("requestCharged", requestCharged)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
  ) extends zio.aws.s3.model.GetObjectTorrentResponse.ReadOnly {
    override val requestCharged: Optional[zio.aws.s3.model.RequestCharged] =
      zio.aws.core.internal
        .optionalFromNullable(impl.requestCharged())
        .map(value => zio.aws.s3.model.RequestCharged.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
  ): zio.aws.s3.model.GetObjectTorrentResponse.ReadOnly = new Wrapper(impl)
}

==> zio-aws-s3_3-5.17.158.4-sources.jar: zio/aws/s3/model/GetObjectTorrentResponse.scala <==
package zio.aws.s3.model
import zio.ZIO
import zio.aws.core.{AwsError, BuilderHelper}
import scala.jdk.CollectionConverters.*
final case class GetObjectTorrentResponse(
    requestCharged: Option[zio.aws.s3.model.RequestCharged] = None
) {
  def buildAwsValue()
      : software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse = {
    import GetObjectTorrentResponse.zioAwsBuilderHelper.BuilderOps
    software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
      .builder()
      .optionallyWith(requestCharged.map(value => value.unwrap))(
        _.requestCharged
      )
      .build()
  }
  def asReadOnly: zio.aws.s3.model.GetObjectTorrentResponse.ReadOnly =
    zio.aws.s3.model.GetObjectTorrentResponse.wrap(buildAwsValue())
}
object GetObjectTorrentResponse {
  private lazy val zioAwsBuilderHelper: BuilderHelper[
    software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
  ] = BuilderHelper.apply
  trait ReadOnly {
    def asEditable: zio.aws.s3.model.GetObjectTorrentResponse = zio.aws.s3.model
      .GetObjectTorrentResponse(requestCharged.map(value => value))
    def requestCharged: Option[zio.aws.s3.model.RequestCharged]
    def getRequestCharged: ZIO[Any, AwsError, zio.aws.s3.model.RequestCharged] =
      AwsError.unwrapOptionField("requestCharged", requestCharged)
  }
  private final class Wrapper(
      impl: software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
  ) extends zio.aws.s3.model.GetObjectTorrentResponse.ReadOnly {
    override val requestCharged: Option[zio.aws.s3.model.RequestCharged] = scala
      .Option(impl.requestCharged())
      .map(value => zio.aws.s3.model.RequestCharged.wrap(value))
  }
  def wrap(
      impl: software.amazon.awssdk.services.s3.model.GetObjectTorrentResponse
  ): zio.aws.s3.model.GetObjectTorrentResponse.ReadOnly = new Wrapper(impl)
}
